package com.hp.user.service.impl;

import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.AddressVO;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.AddressService;
import com.hp.user.service.dao.AddressMapper;
import com.hp.user.service.entity.Address;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 用户地址信息 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class AddressServiceImpl implements AddressService {
    @Autowired
    private AddressMapper addressMapper;
    @Override
    public Result insert(AddressVO address) {
        Address temp = new Address();
        Result result = new Result();
        int flag=0;
        try{
            BeanUtils.copyProperties(address,temp);
            flag = addressMapper.insert(temp);
        }catch (Exception e){

        }
        // 判断数据库操作是否成功
        if(SqlHelper.retBool(flag)){
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("添加失败");
        }
        return result;
    }

    @Override
    public Result update(AddressVO address) {
        Address temp = new Address();
        Result result = new Result();
        int flag=0;
        try{
            BeanUtils.copyProperties(address,temp);
            flag = addressMapper.updateById(temp);
        }catch(Exception e){

        }
        // 判断数据库操作是否成功
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("更新失败");
        }
        return result;
    }

    @Override
    public Result delete(String addressId) {
        Address temp;
        int flag=0;
        Result result = new Result();
        try{
            temp = addressMapper.selectById(addressId);
            if (temp == null) {
                result.setCode("-1");
                result.setMessage("未查找到此地址");
                return result;
            }
            temp.setSysDeleted((short)1);
            flag = addressMapper.updateById(temp);
        }catch (Exception e){

        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("删除失败");
        }
        return result;
    }

    @Override
    public DataResult<AddressVO> queryAddressByAddressId(String addressId) {
        AddressVO addressVO = new AddressVO();
        DataResult<AddressVO> result = new DataResult<>();
        try{
            Address temp = addressMapper.selectById(addressId);
            if (temp==null || temp.getSysDeleted()==1) {
                result.setCode("-1");
                result.setMessage("地址不存在/已删除");
                return result;
            }else{
                BeanUtils.copyProperties(temp,addressVO);
                result.setCode("0");
                result.setData(addressVO);
            }
        }catch (Exception e){

        }
        return result;
    }

    @Override
    public ListResult<AddressVO> queryAllAddress() {
        List<AddressVO> addressVOs=new ArrayList<>();
        ListResult<AddressVO> result = new ListResult<>();
        try{
            List<Address> addresses = addressMapper.selectList(null);
            AddressVO temp;
            for (Address address : addresses){
                temp = new AddressVO();
                BeanUtils.copyProperties(address, temp);
                addressVOs.add(temp);
            }
            result.setCode("0");
            result.setDataList(addressVOs);
        }catch (Exception e){

        }
        return result;
    }
}
